==> approval-1.0.18.tgz: package/webpack.config.js <==
var path = require('path')
var webpack = require('webpack')
var autoprefixer = require('autoprefixer');
var precss = require('precss');

module.exports = {
  devtool: 'cheap-module-eval-source-map', //нужен source-map для отладки кода https://webpack.github.io/docs/configuration.html#devtool
  entry: [ // указывается откуда webpack'у начинать сборку
    'webpack-hot-middleware/client', //команда для поддержки hot-reload, https://www.npmjs.com/package/webpack-hot-middleware
    './src/index.js'
  ],
  output: { //куда сгенерировать сборку
    path: path.join(__dirname, 'dist'),
    filename: 'bundle.js',
    publicPath: '/static/'
  },
  resolve: {
      modulesDirectories: ['node_modules', 'components', 'containers'],
      extensions: ['', '.js']
  },
  plugins: [ //плагины
    // Webpack https://www.npmjs.com/package/webpack-hot-middleware
    new webpack.optimize.OccurenceOrderPlugin(),
    new webpack.HotModuleReplacementPlugin(),

    // new webpack.NoErrorsPlugin() //если в сборке ошибки, то файл сборки не обновляется. В последних версиях не нужно использовать
  ],
  module: {
    preLoaders: [ //добавили ESlint в preloaders
      {
        test: /\.js$/,
        loaders: ['eslint'],
        include: [
          path.resolve(__dirname, 'src'),
        ],
      }
    ],
    loaders: [
      {
        test: /\.js$/,
        loaders: [ 'react-hot', 'babel-loader' ],
        exclude: /node_modules/,
        include: __dirname
      },
      {
          test:   /\.css$/,
          loader: "style-loader!css-loader?modules&importLoaders=1!postcss-loader"
      }
    ]
  },
  postcss: function () {
    return [precss, autoprefixer];
  }
}

==> approval-1.0.22.tgz: package/webpack.config.js <==
var path = require('path')
var webpack = require('webpack')
var autoprefixer = require('autoprefixer');
var precss = require('precss');

module.exports = {
  devtool: 'cheap-module-eval-source-map', //нужен source-map для отладки кода https://webpack.github.io/docs/configuration.html#devtool
  entry: [ // указывается откуда webpack'у начинать сборку
    'webpack-hot-middleware/client', //команда для поддержки hot-reload, https://www.npmjs.com/package/webpack-hot-middleware
    './src/index.js'
  ],
  output: { //куда сгенерировать сборку
    path: path.join(__dirname, 'dist'),
    filename: 'bundle.js',
    publicPath: '/static/'
  },
  resolve: {
      modulesDirectories: ['node_modules', 'components', 'containers', 'reducers'],
      extensions: ['', '.js']
  },
  plugins: [ //плагины
    // Webpack https://www.npmjs.com/package/webpack-hot-middleware
    new webpack.optimize.OccurenceOrderPlugin(),
    new webpack.HotModuleReplacementPlugin(),

    // new webpack.NoErrorsPlugin() //если в сборке ошибки, то файл сборки не обновляется. В последних версиях не нужно использовать
  ],
  module: {
    preLoaders: [ //добавили ESlint в preloaders
      {
        test: /\.js$/,
        loaders: ['eslint'],
        include: [
          path.resolve(__dirname, 'src'),
        ],
      }
    ],
    loaders: [
      {
        test: /\.js$/,
        loaders: [ 'react-hot', 'babel-loader' ],
        exclude: /node_modules/,
        include: __dirname
      },
      {
          test:   /\.css$/,
          loader: "style-loader!css-loader?modules&importLoaders=1!postcss-loader"
      }
    ]
  },
  postcss: function () {
    return [precss, autoprefixer];
  }
}
